---
name: Bug report
about: Create a report to help us improve

---

**Describe the bug**
A clear and concise description of what the bug is.
what is the current behavior

**What is the expected behavior?**
 What is the motivation / use case for changing the behavior?

**To Reproduce**
Steps to reproduce the behavior:
Please provide a minimal working example of the bug if possible.

**Environment (please complete the following information):**
 - Operating System: [all | Windows | Mac | Linux | BSD]
 - What compiler or setup process did you use?
 - Which version/commit of the library did you use?

**Additional context and information**
(e.g. detailed explanation, stacktraces, related issues, suggestions how to fix, links for us to have context, eg. stackoverflow, gitter, etc)
